You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@groovy.apache.org by pa...@apache.org on 2018/09/12 23:16:38 UTC

[1/2] groovy git commit: bump Java 1.6 test usage to 1.7 to make test suite pass on JDK12

Repository: groovy
Updated Branches:
  refs/heads/GROOVY_2_5_X b9f85fd32 -> 80fe71566


bump Java 1.6 test usage to 1.7 to make test suite pass on JDK12


Project: http://git-wip-us.apache.org/repos/asf/groovy/repo
Commit: http://git-wip-us.apache.org/repos/asf/groovy/commit/b9dab0a8
Tree: http://git-wip-us.apache.org/repos/asf/groovy/tree/b9dab0a8
Diff: http://git-wip-us.apache.org/repos/asf/groovy/diff/b9dab0a8

Branch: refs/heads/GROOVY_2_5_X
Commit: b9dab0a887bb76acf062229be860906223c6ece0
Parents: b9f85fd
Author: Paul King <pa...@asert.com.au>
Authored: Wed Sep 12 22:51:15 2018 +1000
Committer: Paul King <pa...@asert.com.au>
Committed: Thu Sep 13 09:10:08 2018 +1000

----------------------------------------------------------------------
 gradle/test.gradle                                               | 4 ++--
 src/test/org/codehaus/groovy/classgen/GenericsGenTest.groovy     | 2 +-
 .../src/test-resources/org/codehaus/groovy/ant/GroovycTest.xml   | 2 +-
 3 files changed, 4 insertions(+), 4 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/groovy/blob/b9dab0a8/gradle/test.gradle
----------------------------------------------------------------------
diff --git a/gradle/test.gradle b/gradle/test.gradle
index 2abca7c..a2dae8a 100644
--- a/gradle/test.gradle
+++ b/gradle/test.gradle
@@ -142,8 +142,8 @@ task compileTestExtensionModule(type: JavaCompile) {
     classpath = files(jar)
     source fileTree("$extModuleFixtureDir/src/main/java")
     destinationDir = file("$extModuleOutputDir/classes")
-    sourceCompatibility = 1.6
-    targetCompatibility = 1.6
+    sourceCompatibility = 1.7
+    targetCompatibility = 1.7
 }
 
 task testExtensionModuleJar(type: Jar) {

http://git-wip-us.apache.org/repos/asf/groovy/blob/b9dab0a8/src/test/org/codehaus/groovy/classgen/GenericsGenTest.groovy
----------------------------------------------------------------------
diff --git a/src/test/org/codehaus/groovy/classgen/GenericsGenTest.groovy b/src/test/org/codehaus/groovy/classgen/GenericsGenTest.groovy
index 6d959a9..f3d39f9 100644
--- a/src/test/org/codehaus/groovy/classgen/GenericsGenTest.groovy
+++ b/src/test/org/codehaus/groovy/classgen/GenericsGenTest.groovy
@@ -66,7 +66,7 @@ class GenericsGenTest extends GroovyTestCase {
         config.targetDirectory = createTempDir("groovy-target-", "-target")
         config.jointCompilationOptions = [
                 "stubDir": createTempDir("groovy-stub-", "-stub"),
-                "namedValues": ["target", "1.6", "source", "1.6"] as String[]
+                "namedValues": ["target", "1.7", "source", "1.7"] as String[]
         ]
         config.classpath = "target/classes"
         FileSystemCompiler compiler = new FileSystemCompiler(config)

http://git-wip-us.apache.org/repos/asf/groovy/blob/b9dab0a8/subprojects/groovy-ant/src/test-resources/org/codehaus/groovy/ant/GroovycTest.xml
----------------------------------------------------------------------
diff --git a/subprojects/groovy-ant/src/test-resources/org/codehaus/groovy/ant/GroovycTest.xml b/subprojects/groovy-ant/src/test-resources/org/codehaus/groovy/ant/GroovycTest.xml
index 05e33f4..2a3f68b 100644
--- a/subprojects/groovy-ant/src/test-resources/org/codehaus/groovy/ant/GroovycTest.xml
+++ b/subprojects/groovy-ant/src/test-resources/org/codehaus/groovy/ant/GroovycTest.xml
@@ -25,7 +25,7 @@
     <property name="srcPath" value="."/>
     <property name="destPath" value="${user.dir}/target/classes/groovy/test"/>
 
-    <property name="javaVersion" value="6"/>
+    <property name="javaVersion" value="7"/>
 
     <path id="groovyMaterials">
         <pathelement path="${java.class.path}"/>


[2/2] groovy git commit: GROOVY-8784: Prepare for supporting JDK 12 bytecode (plus deprecate some old constants)

Posted by pa...@apache.org.
GROOVY-8784: Prepare for supporting JDK 12 bytecode (plus deprecate some old constants)


Project: http://git-wip-us.apache.org/repos/asf/groovy/repo
Commit: http://git-wip-us.apache.org/repos/asf/groovy/commit/80fe7156
Tree: http://git-wip-us.apache.org/repos/asf/groovy/tree/80fe7156
Diff: http://git-wip-us.apache.org/repos/asf/groovy/diff/80fe7156

Branch: refs/heads/GROOVY_2_5_X
Commit: 80fe715668fd61350d5ce01a40e4fbfb7718a81a
Parents: b9dab0a
Author: Paul King <pa...@asert.com.au>
Authored: Thu Sep 13 07:18:17 2018 +1000
Committer: Paul King <pa...@asert.com.au>
Committed: Thu Sep 13 09:15:21 2018 +1000

----------------------------------------------------------------------
 .../groovy/control/CompilerConfiguration.java      | 17 ++++++++++++++---
 1 file changed, 14 insertions(+), 3 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/groovy/blob/80fe7156/src/main/java/org/codehaus/groovy/control/CompilerConfiguration.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/codehaus/groovy/control/CompilerConfiguration.java b/src/main/java/org/codehaus/groovy/control/CompilerConfiguration.java
index c25a229..02dc79f 100644
--- a/src/main/java/org/codehaus/groovy/control/CompilerConfiguration.java
+++ b/src/main/java/org/codehaus/groovy/control/CompilerConfiguration.java
@@ -70,11 +70,21 @@ public class CompilerConfiguration {
     public static final String JDK10 = "10";
     /** This (<code>"11"</code>) is the value for targetBytecode to compile for a JDK 11. **/
     public static final String JDK11 = "11";
+    /** This (<code>"12"</code>) is the value for targetBytecode to compile for a JDK 12. **/
+    public static final String JDK12 = "12";
 
-    /** This (<code>"1.5"</code>) is the value for targetBytecode to compile for a JDK 1.5 or later JVM. **/
+    /**
+     * This constant is for comparing targetBytecode to ensure it is set to JDK 1.5 or later.
+     * @deprecated
+     */
+    @Deprecated
     public static final String POST_JDK5 = JDK5; // for backwards compatibility
 
-    /** This (<code>"1.4"</code>) is the value for targetBytecode to compile for a JDK 1.4 JVM. **/
+    /**
+     * This constant is for comparing targetBytecode to ensure it is set to an earlier value than JDK 1.5.
+     * @deprecated
+     */
+    @Deprecated
     public static final String PRE_JDK5 = JDK4;
 
     /** JDK version to bytecode version mapping */
@@ -86,7 +96,8 @@ public class CompilerConfiguration {
             JDK8, Opcodes.V1_8,
             JDK9, Opcodes.V9,
             JDK10, Opcodes.V10,
-            JDK11, Opcodes.V11
+            JDK11, Opcodes.V11,
+            JDK12, Opcodes.V12
     );
 
     /** An array of the valid targetBytecode values **/